@@ -671,7 +671,18 @@ class Dataset():
                                   settigs_entity=column_code_settings,
                                   entity_type=column_code_settings['parameterType'], dataset_type=self._dataset_type)
 
-    def set_synonym(self,column_code: str,synonyms: list, replace=False):
+    def set_parameter_name(self, column_code: str, name: str):
+        column_code_settings = self.__retrive_entity(entity_code=column_code, dataset_id=self._dataset_id,
+                                                     dataset_type=self._dataset_type)
+
+        column_code_settings['name'] = name
+
+
+        self.__put_entity_dataset(entity_code=column_code_settings['code'], dataset_id=self._dataset_id,
+                                  settigs_entity=column_code_settings,
+                                  entity_type=column_code_settings['parameterType'], dataset_type=self._dataset_type)
+
+    def set_synonym(self, column_code: str, synonyms: list, replace=False):
         """
         set the synonym of column_code of specific dataset instantiated with slug
 
