@@ -743,6 +743,31 @@ class Insight_Definition:
         r = s.put(url=url, json=entity_settings, headers=headers)
         r.raise_for_status()
 
+    def add_to_channel(self, original_channel_id, new_channel_id):
+        url = self._base_url_askdata + "/smartfeed/pin/pinned/"+original_channel_id+"?addMode=true"
+        body = [
+            {
+                "targetId": new_channel_id,
+                "type": "CARD",
+                "pinnedValues": {}
+            }
+        ]
+        # logging.info("URL: {}".format(url))
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+
+
+
     def edit_data_name(self, data_id, component_name):
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/data_queries/"+data_id
         body = {
@@ -1287,7 +1312,7 @@ class Insight_Definition:
                 "userId": r.json()[0]["id"]
             }
 
-            url = self.smart_insight_url+"/insights/8a09ec79-8e1e-401a-bdec-70d33c9c1543/users"
+            url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
 
             s = requests.Session()
             s.keep_alive = False
@@ -1328,7 +1353,7 @@ class Insight_Definition:
                 "userId": r.json()[0]["id"]
             }
 
-            url = self.smart_insight_url+"/insights/8a09ec79-8e1e-401a-bdec-70d33c9c1543/users"
+            url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
 
             s = requests.Session()
             s.keep_alive = False
