@@ -309,7 +309,7 @@ class Query:
                                      "int1", "ubigint", "uinteger", "usmallint",
                                      "utinyint", "bool", "boolean", "mediumint",
                                      "double precision", "dec", "smallserial", "serial",
-                                     "bigserial", "number"],
+                                     "bigserial", "number", "binary", "smalldecimal"],
                                 "date":
                                     ["date", "datetimeoffset", "datetime2", "smalldatetime",
                                      "timestamp", "datetime", "time", "year",
@@ -317,7 +317,9 @@ class Query:
                                 "string":
                                     ["string", "varchar", "varchar2", "char",
                                      "bpchar", "text", "nchar", "nvarchar",
-                                     "ntext", "tinytext", "mediumtext", "longtext",
+                                     "tinyblob", "blob", "shorttext", "clob",
+                                     "nclob", "ntext", "tinytext", "mediumtext",
+                                     "longtext", "mediumblob", "longblob", "image",
                                      "character", "character varying", "binary", "varbinary"]}
 
         for where_condition in where:
@@ -389,7 +391,7 @@ class Query:
                                      "int1", "ubigint", "uinteger", "usmallint",
                                      "utinyint", "bool", "boolean", "mediumint",
                                      "double precision", "dec", "smallserial", "serial",
-                                     "bigserial", "number"],
+                                     "bigserial", "number", "binary", "smalldecimal"],
                                 "date":
                                     ["date", "datetimeoffset", "datetime2", "smalldatetime",
                                      "timestamp", "datetime", "time", "year",
@@ -397,7 +399,9 @@ class Query:
                                 "string":
                                     ["string", "varchar", "varchar2", "char",
                                      "bpchar", "text", "nchar", "nvarchar",
-                                     "ntext", "tinytext", "mediumtext", "longtext",
+                                     "tinyblob", "blob", "shorttext", "clob",
+                                     "nclob", "ntext", "tinytext", "mediumtext",
+                                     "longtext", "mediumblob", "longblob", "image",
                                      "character", "character varying", "binary", "varbinary"]}
 
         fields = []
@@ -552,8 +556,10 @@ class Query:
                 else:
                     operator = None
 
-                if ("measure" in where_condition.field.internalDataType.lower() and "measure" not in where_condition.field.sourceDataType.lower()) or \
-                        ("dimension" in where_condition.field.internalDataType.lower() and "dimension" not in where_condition.field.sourceDataType.lower()):
+                if (
+                        "measure" in where_condition.field.internalDataType.lower() and "measure" not in where_condition.field.sourceDataType.lower()) or \
+                        (
+                                "dimension" in where_condition.field.internalDataType.lower() and "dimension" not in where_condition.field.sourceDataType.lower()):
                     # if internal and original data types are not consistent each other use this pattern
                     # aggregation column (original data type, to internal data type ) AS Alias
                     formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
@@ -601,7 +607,8 @@ class Query:
             else:
                 # otherwise, check if internal and original data types are not consistent each other
                 if ("measure" in field.internalDataType.lower() and "measure" not in field.sourceDataType.lower()) or \
-                        ("dimension" in field.internalDataType.lower() and "dimension" not in field.sourceDataType.lower()):
+                        (
+                                "dimension" in field.internalDataType.lower() and "dimension" not in field.sourceDataType.lower()):
                     # if internal and original data types are not consistent each other use this pattern
                     # aggregation column (original data type, to internal data type ) AS Alias
                     if field.alias is None:
